==> zio-aws-cognitoidentityprovider_2.13-5.17.104.1-sources.jar: zio/aws/cognitoidentityprovider/model/GetUserPoolMfaConfigResponse.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetUserPoolMfaConfigResponse(
    smsMfaConfiguration: Option[
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType
    ] = None,
    softwareTokenMfaConfiguration: Option[
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType
    ] = None,
    mfaConfiguration: Option[
      zio.aws.cognitoidentityprovider.model.UserPoolMfaType
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse = {
    import GetUserPoolMfaConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
      .builder()
      .optionallyWith(smsMfaConfiguration.map(value => value.buildAwsValue()))(
        _.smsMfaConfiguration
      )
      .optionallyWith(
        softwareTokenMfaConfiguration.map(value => value.buildAwsValue())
      )(_.softwareTokenMfaConfiguration)
      .optionallyWith(mfaConfiguration.map(value => value.unwrap))(
        _.mfaConfiguration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse.ReadOnly =
    zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
      .wrap(buildAwsValue())
}
object GetUserPoolMfaConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse =
      zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse(
        smsMfaConfiguration.map(value => value.asEditable),
        softwareTokenMfaConfiguration.map(value => value.asEditable),
        mfaConfiguration.map(value => value)
      )
    def smsMfaConfiguration: Option[
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.ReadOnly
    ]
    def softwareTokenMfaConfiguration: Option[
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType.ReadOnly
    ]
    def mfaConfiguration
        : Option[zio.aws.cognitoidentityprovider.model.UserPoolMfaType]
    def getSmsMfaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.ReadOnly
    ] = AwsError.unwrapOptionField("smsMfaConfiguration", smsMfaConfiguration)
    def getSoftwareTokenMfaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType.ReadOnly
    ] = AwsError.unwrapOptionField(
      "softwareTokenMfaConfiguration",
      softwareTokenMfaConfiguration
    )
    def getMfaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.UserPoolMfaType
    ] = AwsError.unwrapOptionField("mfaConfiguration", mfaConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
  ) extends zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse.ReadOnly {
    override val smsMfaConfiguration: Option[
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.ReadOnly
    ] = scala
      .Option(impl.smsMfaConfiguration())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.wrap(value)
      )
    override val softwareTokenMfaConfiguration: Option[
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType.ReadOnly
    ] = scala
      .Option(impl.softwareTokenMfaConfiguration())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType
          .wrap(value)
      )
    override val mfaConfiguration
        : Option[zio.aws.cognitoidentityprovider.model.UserPoolMfaType] = scala
      .Option(impl.mfaConfiguration())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.UserPoolMfaType.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
  ): zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitoidentityprovider_2.13-5.17.201.2-sources.jar: zio/aws/cognitoidentityprovider/model/GetUserPoolMfaConfigResponse.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetUserPoolMfaConfigResponse(
    smsMfaConfiguration: Optional[
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType
    ] = Optional.Absent,
    softwareTokenMfaConfiguration: Optional[
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType
    ] = Optional.Absent,
    mfaConfiguration: Optional[
      zio.aws.cognitoidentityprovider.model.UserPoolMfaType
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse = {
    import GetUserPoolMfaConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
      .builder()
      .optionallyWith(smsMfaConfiguration.map(value => value.buildAwsValue()))(
        _.smsMfaConfiguration
      )
      .optionallyWith(
        softwareTokenMfaConfiguration.map(value => value.buildAwsValue())
      )(_.softwareTokenMfaConfiguration)
      .optionallyWith(mfaConfiguration.map(value => value.unwrap))(
        _.mfaConfiguration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse.ReadOnly =
    zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
      .wrap(buildAwsValue())
}
object GetUserPoolMfaConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse =
      zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse(
        smsMfaConfiguration.map(value => value.asEditable),
        softwareTokenMfaConfiguration.map(value => value.asEditable),
        mfaConfiguration.map(value => value)
      )
    def smsMfaConfiguration: Optional[
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.ReadOnly
    ]
    def softwareTokenMfaConfiguration: Optional[
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType.ReadOnly
    ]
    def mfaConfiguration
        : Optional[zio.aws.cognitoidentityprovider.model.UserPoolMfaType]
    def getSmsMfaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.ReadOnly
    ] = AwsError.unwrapOptionField("smsMfaConfiguration", smsMfaConfiguration)
    def getSoftwareTokenMfaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType.ReadOnly
    ] = AwsError.unwrapOptionField(
      "softwareTokenMfaConfiguration",
      softwareTokenMfaConfiguration
    )
    def getMfaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.UserPoolMfaType
    ] = AwsError.unwrapOptionField("mfaConfiguration", mfaConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
  ) extends zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse.ReadOnly {
    override val smsMfaConfiguration: Optional[
      zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.smsMfaConfiguration())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.SmsMfaConfigType.wrap(value)
      )
    override val softwareTokenMfaConfiguration: Optional[
      zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.softwareTokenMfaConfiguration())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.SoftwareTokenMfaConfigType
          .wrap(value)
      )
    override val mfaConfiguration
        : Optional[zio.aws.cognitoidentityprovider.model.UserPoolMfaType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mfaConfiguration())
        .map(value =>
          zio.aws.cognitoidentityprovider.model.UserPoolMfaType.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse
  ): zio.aws.cognitoidentityprovider.model.GetUserPoolMfaConfigResponse.ReadOnly =
    new Wrapper(impl)
}
